==> tuia-commercial-center-api-0.0.1-20190529.165206-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/common/MissionDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.common;

import java.io.Serializable;

/**
 * [商业化活动]种红包任务Dto
 *
 * @author zhangbaiqiang
 * @date 2019/03/08
 */
public class MissionDto implements Serializable {
    private static final long serialVersionUID = 5161553706815899246L;

    /**
     * 任务编号
     */
    private String id;

    /**
     * 任务类型
     */
    private String type;

    /**
     * 图片链接
     */
    private String picUrl;

    /**
     * 奖励描述
     */
    private String prizeDesc;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务进度
     */
    private String progress;

    /**
     * 明日任务预览
     */
    private Boolean preview;

    /**
     * 任务进度
     */
    private Integer status;

    /**
     * 区块ID
     */
    private Long blockId;

    /**
     * 排序值（数值越大优先级越高）
     */
    private Integer order;

    /*
     * 任务对应的落地页连接（特定皮肤中会存在直接跳到落地页的任务）
     */
    private String landingPageUrl;

    /*
     * 任务对应的落地页弹层图片连接（特定皮肤中会存在直接跳到落地页的任务）
     */
    private String landingPageImgUrl;

    public String getLandingPageUrl() {
        return landingPageUrl;
    }

    public void setLandingPageUrl(String landingPageUrl) {
        this.landingPageUrl = landingPageUrl;
    }

    public String getLandingPageImgUrl() {
        return landingPageImgUrl;
    }

    public void setLandingPageImgUrl(String landingPageImgUrl) {
        this.landingPageImgUrl = landingPageImgUrl;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getPrizeDesc() {
        return prizeDesc;
    }

    public void setPrizeDesc(String prizeDesc) {
        this.prizeDesc = prizeDesc;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getProgress() {
        return progress;
    }

    public void setProgress(String progress) {
        this.progress = progress;
    }

    public Boolean getPreview() {
        return preview;
    }

    public void setPreview(Boolean preview) {
        this.preview = preview;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getBlockId() {
        return blockId;
    }

    public void setBlockId(Long blockId) {
        this.blockId = blockId;
    }

    public Integer getOrder() {
        return order;
    }

    public void setOrder(Integer order) {
        this.order = order;
    }
}

==> tuia-commercial-center-api-1.0.17-20191125.105531-1-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/common/MissionDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.common;

import java.io.Serializable;

/**
 * [商业化活动]种红包任务Dto
 *
 * @author zhangbaiqiang
 * @date 2019/03/08
 */
public class MissionDto implements Serializable {
    private static final long serialVersionUID = 5161553706815899246L;

    /**
     * 任务编号
     */
    private String id;

    /**
     * 任务类型
     */
    private String type;

    /**
     * 图片链接
     */
    private String picUrl;

    /**
     * 奖励描述
     */
    private String prizeDesc;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务进度
     */
    private String progress;

    /**
     * 明日任务预览
     */
    private Boolean preview;

    /**
     * 任务进度
     */
    private Integer status;

    /**
     * 区块ID
     */
    private Long blockId;

    /**
     * 排序值（数值越大优先级越高）
     */
    private Integer order;

    /**
     * 任务对应的落地页连接（特定皮肤中会存在直接跳到落地页的任务）
     */
    private String landingPageUrl;

    /**
     * 任务对应的落地页弹层图片连接（特定皮肤中会存在直接跳到落地页的任务）
     */
    private String landingPageImgUrl;

    /**
     * 闯关任务场景解锁图片
     */
    private String sceneImgUrl;

    /**
     * 闯关任务标题
     */
    private String sceneTitle;

    /**
     * 进度（因为progress被占用了，所以加个i）
     */
    private Integer intProgress;

    /**
     * 目标（progress加了个i，保持一致）
     */
    private Integer intTarget;

    /**
     * 任务类型
     */
    private String missionType;

    public String getLandingPageUrl() {
        return landingPageUrl;
    }

    public void setLandingPageUrl(String landingPageUrl) {
        this.landingPageUrl = landingPageUrl;
    }

    public String getLandingPageImgUrl() {
        return landingPageImgUrl;
    }

    public void setLandingPageImgUrl(String landingPageImgUrl) {
        this.landingPageImgUrl = landingPageImgUrl;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getPrizeDesc() {
        return prizeDesc;
    }

    public void setPrizeDesc(String prizeDesc) {
        this.prizeDesc = prizeDesc;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getProgress() {
        return progress;
    }

    public void setProgress(String progress) {
        this.progress = progress;
    }

    public Boolean getPreview() {
        return preview;
    }

    public void setPreview(Boolean preview) {
        this.preview = preview;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getBlockId() {
        return blockId;
    }

    public void setBlockId(Long blockId) {
        this.blockId = blockId;
    }

    public Integer getOrder() {
        return order;
    }

    public void setOrder(Integer order) {
        this.order = order;
    }

    public String getSceneImgUrl() {
        return sceneImgUrl;
    }

    public void setSceneImgUrl(String sceneImgUrl) {
        this.sceneImgUrl = sceneImgUrl;
    }

    public String getSceneTitle() {
        return sceneTitle;
    }

    public void setSceneTitle(String sceneTitle) {
        this.sceneTitle = sceneTitle;
    }

    public Integer getIntProgress() {
        return intProgress;
    }

    public void setIntProgress(Integer intProgress) {
        this.intProgress = intProgress;
    }

    public Integer getIntTarget() {
        return intTarget;
    }

    public void setIntTarget(Integer intTarget) {
        this.intTarget = intTarget;
    }

    public String getMissionType() {
        return missionType;
    }

    public void setMissionType(String missionType) {
        this.missionType = missionType;
    }
}
